@@ -1,18 +1,17 @@
-
-finalize_bootstrap <- function(x) {
-  if (!isTRUE(meta(x)$output == "html")) {
-    return(x)
-  }
+setMethod(
+  f = "finalize",
+  signature = "tinytable_bootstrap",
+  definition = function(x, ...) {
 
   # class
-  cl <- meta(x, "bootstrap_class")
-  if (is.null(cl)) {
+  cl <- x@bootstrap_class
+  if (is.null(cl) || length(cl) == 0) {
     cl <- "table table-borderless"
   }
   out <- sub(
     "$tinytable_BOOTSTRAP_CLASS",
     cl,
-    x,
+    x@table_string,
     fixed = TRUE)
 
   # Rmarkdown and Quarto load their own bootstrap, which we probably don't want to override
@@ -22,5 +21,11 @@ finalize_bootstrap <- function(x) {
     out <- paste(out, collapse = "\n")
   }
 
-  return(out)
-}
\ No newline at end of file
+  x@table_string <- out
+
+  for (fn in x@lazy_finalize) {
+    x <- fn(x)
+  }
+
+  return(x)
+})
\ No newline at end of file
